@@ -20,7 +20,7 @@
 
 import os
 import json
-import flexmock
+from flexmock import flexmock
 from itertools import chain
 
 from thoth.adviser.product import Product
@@ -254,6 +254,7 @@ black = true
             os_name="fedora",
             os_version="31",
             python_version="3.7",
+            marker_evaluation_result=True,
         ).and_return("python_version >= '3.7'").once()
 
         assert "THOTH_ADVISER_METADATA" not in os.environ
@@ -333,6 +334,7 @@ black = true
                 "operating_system": {"name": "rhel", "version": None},
                 "python_version": None,
                 "cuda_version": None,
+                "labels": None,
                 "cudnn_version": None,
                 "name": None,
                 "platform": None,
@@ -466,6 +468,7 @@ black = true
             os_name="fedora",
             os_version="31",
             python_version="3.7",
+            marker_evaluation_result=True,
         ).and_return("python_version >= '3.7'").and_return("python_version >= '3' or 1").twice()
 
         product = Product.from_final_state(context=context, state=state)
@@ -539,6 +542,7 @@ black = true
                     "hardware": {"cpu_family": None, "cpu_model": None, "gpu_model": None},
                     "name": None,
                     "operating_system": {"name": None, "version": None},
+                    "labels": None,
                     "openblas_version": None,
                     "openmpi_version": None,
                     "mkl_version": None,
@@ -623,6 +627,7 @@ black = true
             os_name="fedora",
             os_version="31",
             python_version="3.7",
+            marker_evaluation_result=True,
         ).and_return("python_version >= '3.7'").once()
 
         product = Product.from_final_state(context=context, state=state)
@@ -705,6 +710,7 @@ black = true
                     "name": None,
                     "operating_system": {"name": None, "version": None},
                     "openblas_version": None,
+                    "labels": None,
                     "openmpi_version": None,
                     "mkl_version": None,
                     "python_version": None,
@@ -795,6 +801,7 @@ black = true
             os_name="fedora",
             os_version="31",
             python_version="3.7",
+            marker_evaluation_result=True,
         ).and_return("python_version >= '3.8'").once()
 
         context.graph.should_receive("get_python_environment_marker").with_args(
@@ -806,6 +813,7 @@ black = true
             os_name="fedora",
             os_version="31",
             python_version="3.7",
+            marker_evaluation_result=True,
         ).and_return(None).once()
 
         product = Product.from_final_state(context=context, state=state)
@@ -859,6 +867,7 @@ black = true
                     "hardware": {"cpu_family": None, "cpu_model": None, "gpu_model": None},
                     "name": None,
                     "operating_system": {"name": None, "version": None},
+                    "labels": None,
                     "platform": None,
                     "mkl_version": None,
                     "openmpi_version": None,
@@ -948,6 +957,7 @@ black = true
                     "hardware": {"cpu_family": None, "cpu_model": None, "gpu_model": None},
                     "name": None,
                     "operating_system": {"name": None, "version": None},
+                    "labels": None,
                     "platform": None,
                     "mkl_version": None,
                     "openmpi_version": None,
