@@ -1,6 +1,6 @@
 #!/usr/bin/env python3
 # thoth-adviser
-# Copyright(C) 2020 Fridolin Pokorny
+# Copyright(C) 2020 - 2021 Fridolin Pokorny
 #
 # This program is free software: you can redistribute it and / or modify
 # it under the terms of the GNU General Public License as published by
@@ -18,14 +18,10 @@
 """Pseudonym units implemented in adviser."""
 
 from ._debug import AliasPseudonym
-from .intel_tensorflow import IntelTensorFlowPseudonym
-from .tensorflow_gpu import TensorFlowGPUPseudonym
 
 # Relative ordering of units is relevant, as the order specifies order
 # in which the asked to be registered - any dependencies between them
 # can be mentioned here.
 __all__ = [
     "AliasPseudonym",
-    "IntelTensorFlowPseudonym",
-    "TensorFlowGPUPseudonym",
 ]
